/******************************************************************************
* ECE532 Digital System Design Course Spring 2007
* Dance Dance Revolution on FPGA
* Jeffrey Puk, Dharmendra Gupta, Kenny Chan
* 
* This file is used to control the drawing of arrow tiles on SVGA and 
* also helps to keep track of all the arrows drawn. The screen is divided into
* 100x75 tiles in 800x600 resolution. Each tile is made up of 8x8 pixels.
******************************************************************************/

#ifndef SVGA_H
#define SVGA_H

#include "xparameters.h"
#include "xutil.h"
#include "xio.h"
#include "stdlib.h"

#define MAXWIDTH 100
#define MAXHEIGHT 75

#define SVGA_OFFSET 0xdbff8000

#ifndef BOOL
#define BOOL int
#endif
#ifndef TRUE
#define TRUE 1
#endif
#ifndef FALSE
#define FALSE 0
#endif

enum direction_t
{
	LEFT=0,
	DOWN=1,
	UP=2,
	RIGHT=3,
};

struct arrow_t
{
	BOOL exist;
	int x,y;
	int direction;
	int color;
	struct arrow_t * next;
};

struct arrow_t ** list;	// list of arrows to draw, each list represents a column
struct arrow_t ** tail;	// list of tail arrows (latest drawn arrows)

//-----------------------------------------------------------------------------
// Low level functions to draw arrow tiles onto screen
void drawArrow(int * pChar_data_wrd, int indexI, int indexJ, int direction, int color);
void clearScreen(int * pChar_data_wrd);
void updateColor(int *tile);
void printScore(int * pChar_data_wrd, int score);

//-----------------------------------------------------------------------------
// High level functions to keep track of arrows drawn
void generateArrows();
void addArrowToList(int column);

void drawGreyArrowsToScreen(int * pChar_data_wrd);
void drawArrowsToScreen(int * pChar_data_wrd);

void checkAndDeleteTailArrow();
void freeAllArrowsFromLists();

#endif
