//     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"
//     SOLELY FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR
//     XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION
//     AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE, APPLICATION
//     OR STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS
//     IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,
//     AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE
//     FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY
//     WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE
//     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
//     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF
//     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
//     FOR A PARTICULAR PURPOSE.
//
//     (c) Copyright 2002 Xilinx, Inc.
//     All rights reserved.
//

/*
-------------------------------------------------------------------------------
   Title      : SVGA Video Output Pixel Data Steering
   Project    : MicroBlaze Demo Board
-------------------------------------------------------------------------------
   File       : DRIVE_DAC_DATA.v
   Company    : Xilinx, Inc.
   Created    : 2001/07/17
   Last Update: 2001/07/17
   Copyright  : (c) Xilinx Inc, 2001
-------------------------------------------------------------------------------
   Uses       : 
-------------------------------------------------------------------------------
   Used by    : CHAR_MODE_SVGA_CTRL.v
-------------------------------------------------------------------------------
   Description: This module enables either the bit-mapped image data from the 
			Video RAMS, or the character-mapped text data from the 
			character BRAMS to be passed to the Video DAC.
-------------------------------------------------------------------------------
 
-------------------------------------------------------------------------------
*/


module DRIVE_DAC_DATA (
bm_red_data, 
bm_green_data, 
bm_blue_data, 
char_red_data, 
char_green_data, 
char_blue_data, 
bm_display_active,
char_display_active,
dac_red_data,
dac_green_data,
dac_blue_data
);

input [7:0] 	bm_red_data;		// bit mapped red data from video memory
input [7:0] 	bm_green_data;		// bit mapped green data from video memory
input [7:0]	bm_blue_data;		// bit mapped blue data from video memory

//FOR VIDEO OVERLAY
input [7:0] 	char_red_data;		// bit mapped red data from video memory
input [7:0] 	char_green_data;		// bit mapped green data from video memory
input [7:0]	char_blue_data;		// bit mapped blue data from video memory
input			bm_display_active;	// flag to make the bm dispaly window active
input			char_display_active;// flag to make the character display active
output [7:0] 	dac_red_data;		// the red data for the video dac
output [7:0] 	dac_green_data;		// the green data for the video dac
output [7:0] 	dac_blue_data;		// the blue data for the video dac

reg [7:0]		dac_red_data;
reg [7:0]		dac_green_data;
reg [7:0]		dac_blue_data;


// DEFINE THE DEFAULT COLORS 
parameter [7:0]
DEFAULT_RED_COLOR   = 8'h00,
DEFAULT_GREEN_COLOR = 8'h00,
DEFAULT_BLUE_COLOR  = 8'h00;

// make the dac connections
always @ (bm_red_data or bm_green_data or bm_blue_data or char_mode_data or bm_display_active or char_display_active) begin
case ({bm_display_active, char_display_active})

2'b00:begin		// both BM and CHAR modes are disabled
	dac_red_data   = DEFAULT_RED_COLOR;
	dac_green_data = DEFAULT_GREEN_COLOR;
	dac_blue_data  = DEFAULT_BLUE_COLOR;
	end
2'b10:begin		// bit mapped portion of the display
	dac_red_data   = bm_red_data;
	dac_green_data = bm_green_data;
	dac_blue_data  = bm_blue_data;
	end
2'b01:begin		// character mapped data is displayed
	dac_red_data   = char_red_data;
	dac_green_data = char_green_data;
	dac_blue_data  = char_blue_data;
	end
2'b11:begin		// BM with CHAR mode overlay
	dac_red_data   = (bm_red_data | char_red_data);
	dac_green_data = (bm_green_data | char_green_data );
	dac_blue_data  = (bm_blue_data | char_blue_data );
	end
endcase
end
endmodule //DRIVE_DAC_DATA








