//////////////////////////////////////////////////////////////////
// average.v
//
// find 32-history n*average and n*din
// Rev 1.0a
// Date Mar 20, 2007
//
// beat.v
//  +multiplier (black box)
//  +accumulator
//  +a_lt_b
//  +mult15.v
//  +average.v
//   +fifon.v
/////////////////////////////////////////////////////////////////

module average(clk, reset, en, din, ndin, navg);
    parameter nbit=5;         //2^nbit history (5)
    parameter n=32;            //CAUTION: must set n = 2^nbit
    parameter p=58; 		//#bit per entry in fifo (58)
    input clk,reset,en;
    input [p-1:0] din;
    output [p+nbit-1:0] ndin, navg;
   
    reg [p+nbit-1:0] navg;

    wire [p-1:0] old_value;
    
    initial begin
        navg = 0;
    end    
    always@(posedge clk) begin
        if(reset) begin
            //set everything to 0
            navg <= 0;
        end
        else if (en) begin
            navg <= navg - old_value + din; // remove last entry of fifo from average, add new value
        end
    end
    
    // push new value into fifo
    fifon queue(clk, reset, en, din, old_value);
       defparam queue.n=n;
       defparam queue.p=p;
    
    // generate a n * din for comparison with average
    assign ndin = din<<nbit;
    
endmodule