//////////////////////////////////////////////////////////////////
// fifon.v
//
// a first in first out queue for storing history
// Rev 1.0a
// Date Mar 20, 2007
//
// beat.v
//  +multiplier (black box)
//  +accumulator
//  +a_lt_b
//  +mult15.v
//  +average.v
//   +fifon.v
/////////////////////////////////////////////////////////////////

module fifon(clk, reset, en, din, dout);
    parameter n=32;         //32 history
    parameter p=58; //58bit number per sample
    input clk,reset,en;
    input [p-1:0] din;
    output [p-1:0] dout;

    reg [n*p-1:0] history; //total number of registers needed is n*p
    
    integer i;
    
    initial begin
        history = 0;
    end    
    always@(posedge clk) begin
        if(reset) begin
            //set everything to 0
            history <= 0;
        end
        else if (en) begin
            //shift p over
            for (i=p; i<n*p; i=i+1) begin
                history[i-p] <= history[i];
            end
            //push input to beginning
            history[n*p-1:(n-1)*p] <= din[p-1:0];
        end
    end
    
    assign dout = history[p-1:0];
    
endmodule