//////////////////////////////////////////////////////////////////
// myfifo.v
//
// Read from AC97 Serial interface and extract the left channel
// Rev 1.0a
// Date Mar 20, 2007
//
// myfifo.v
//  +shift16.v
//  +StepDown.v
/////////////////////////////////////////////////////////////////

module myfifo(bclk, sync, data, out_en, left_out, left_out_im, sclk);
    input bclk, sync;
    input data;
    output out_en;
    output [15:0] left_out, left_out_im;
    output sclk;
    
    reg shift_en, left_en;
    wire [15:0] outout;
    reg [7:0] counter;
    
    
    initial begin
        shift_en = 1;
        left_en=1;
    end

    // begin state machine    
    always @ (posedge bclk or posedge sync) begin
        if (sync) begin
            counter<=0;
        end else begin
           counter <= counter + 1;
       end
    end

    // get 16 bit from left channel (3rd frame) and put in shift reg(20bit per frame, so start at 40)
    always @ (counter) begin
        shift_en=0;
        left_en=0;
        case (counter)
            8'd40:   shift_en=1;
            8'd41:   shift_en=1;
            8'd42:   shift_en=1;
            8'd43:   shift_en=1;
            8'd44:   shift_en=1;
            8'd45:   shift_en=1;
            8'd46:   shift_en=1;
            8'd47:   shift_en=1;
            8'd48:   shift_en=1;
            8'd49:   shift_en=1;
            8'd50:   shift_en=1;
            8'd51:   shift_en=1;
            8'd52:   shift_en=1;
            8'd53:   shift_en=1;
            8'd54:   shift_en=1;
            8'd55:   shift_en=1;
            8'd56:   left_en=1;
        endcase
    end    
    
    shift16 left_channel(bclk, shift_en, data, left_out); // shift data if enabled
    
    StepDown sampling_rate(bclk, sclk); // make 48kHz clock from bit clock (/256)
    
    assign left_out_im = 8'b00000000; // alway real number, no imaginary component;
    assign out_en = 1; //read only, output always ready
    
endmodule